supportsAllPairingKinds property

bool supportsAllPairingKinds
final

Returns true if in-app pairing is possible either by API or by encrypted characteristic using any kind of pairing method (Just Works, Numeric Comparison or Passkey Entry).

All platforms return true except Web/Windows and Web/Linux which return false because they only support "Numeric Comparison" and "Passkey Entry".

For more fine-grained control it is recommended to use triggersConfirmOnlyPairing in conjunction with the pairing method of your device, e.g. if (!BleCapabilities.triggersConfirmOnlyPairing && deviceUsesConfirmOnlyPairing) throw "In-app pairing not supported";

Implementation

static final bool supportsAllPairingKinds =
    triggersConfirmOnlyPairing || hasSystemPairingApi;